pub struct Locator<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Locator<'a>
impl<'a> Locator<'a>
pub const fn new(contents: &'a str) -> Self
pub fn to_index(&self) -> &LineIndex
pub fn to_source_code(&self) -> SourceCode<'_, '_>
Sourcepub fn floor_char_boundary(&self, offset: TextSize) -> TextSize
pub fn floor_char_boundary(&self, offset: TextSize) -> TextSize
Finds the closest TextSize not exceeding the offset for which is_char_boundary is
true.
Examples
let locator = Locator::new("Hello");
assert_eq!(
locator.floor_char_boundary(TextSize::from(0)),
TextSize::from(0)
);
assert_eq!(
locator.floor_char_boundary(TextSize::from(5)),
TextSize::from(5)
);
let locator = Locator::new("α");
assert_eq!(
locator.floor_char_boundary(TextSize::from(0)),
TextSize::from(0)
);
assert_eq!(
locator.floor_char_boundary(TextSize::from(1)),
TextSize::from(0)
);
assert_eq!(
locator.floor_char_boundary(TextSize::from(2)),
TextSize::from(2)
);Trait Implementations
Sourceimpl LineRanges for Locator<'_>
impl LineRanges for Locator<'_>
Sourcefn line_start(&self, offset: TextSize) -> TextSize
fn line_start(&self, offset: TextSize) -> TextSize
Computes the start position of the line of
offset. Read moreSourcefn bom_start_offset(&self) -> TextSize
fn bom_start_offset(&self) -> TextSize
Computes the start position of the file contents: either the first byte, or the byte after
the BOM.
Sourcefn full_line_end(&self, offset: TextSize) -> TextSize
fn full_line_end(&self, offset: TextSize) -> TextSize
Computes the offset that is right after the newline character that ends
offset’s line. Read moreSourcefn line_end(&self, offset: TextSize) -> TextSize
fn line_end(&self, offset: TextSize) -> TextSize
Computes the offset that is right before the newline character that ends
offset’s line. Read moreSourcefn full_line_str(&self, offset: TextSize) -> &str
fn full_line_str(&self, offset: TextSize) -> &str
Returns the text of the
offset’s line. Read moreSourcefn contains_line_break(&self, range: TextRange) -> bool
fn contains_line_break(&self, range: TextRange) -> bool
Returns true if the text of
range contains any line break. Read moreSourcefn lines_str(&self, range: TextRange) -> &str
fn lines_str(&self, range: TextRange) -> &str
Returns the text of all lines that include
range. Read moreSourcefn full_lines_str(&self, range: TextRange) -> &str
fn full_lines_str(&self, range: TextRange) -> &str
Returns the text of all lines that include
range. Read moreSourcefn is_at_start_of_line(&self, offset: TextSize) -> bool
fn is_at_start_of_line(&self, offset: TextSize) -> bool
Returns
true if offset is at the start of a line.Sourcefn full_line_range(&self, offset: TextSize) -> TextRange
fn full_line_range(&self, offset: TextSize) -> TextRange
Computes the range of this
offsets line. Read moreSourcefn line_range(&self, offset: TextSize) -> TextRange
fn line_range(&self, offset: TextSize) -> TextRange
Computes the range of this
offsets line ending before the newline character. Read moreSourcefn full_lines_range(&self, range: TextRange) -> TextRange
fn full_lines_range(&self, range: TextRange) -> TextRange
Computes the range of all lines that this
range covers. Read moreAuto Trait Implementations
impl<'a> !Freeze for Locator<'a>
impl<'a> !RefUnwindSafe for Locator<'a>
impl<'a> !Sync for Locator<'a>
impl<'a> Send for Locator<'a>
impl<'a> Unpin for Locator<'a>
impl<'a> UnsafeUnpin for Locator<'a>
impl<'a> UnwindSafe for Locator<'a>